"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createTokenBundle = void 0;

var _tokenWriter = require("../utils/token-writer");

var _ls = require("../utils/ls");

const UPDATED = 'TOKEN_UPDATED';
const CLEARED = 'TOKEN_CLEARED';

const createTokenBundle = opts => {
  const {
    readToken,
    writeToken,
    clearToken
  } = (0, _tokenWriter.createTokenWriter)(opts);
  return {
    name: 'token',
    getReducer: () => {
      const initial = {
        token: readToken()
      };
      return (state = initial, {
        type,
        payload
      }) => {
        if (type === UPDATED) {
          return Object.assign({}, state, {
            token: payload
          });
        }

        if (type === CLEARED) {
          return Object.assign({}, state, {
            token: null
          });
        }

        return state;
      };
    },
    selectAuthToken: state => state.token.token,
    selectIsSignedIn: state => !!state.token.token,
    doReceiveToken: token => ({
      dispatch
    }) => {
      writeToken(token);
      dispatch({
        type: UPDATED,
        payload: token
      });
    },
    doClearToken: () => ({
      dispatch
    }) => {
      clearToken();
      (0, _ls.clearLocalStorage)();
      dispatch({
        type: CLEARED
      });
    }
  };
};

exports.createTokenBundle = createTokenBundle;