"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FormsSection = void 0;

var _preact = require("preact");

var _2 = require("../");

var _section = _interopRequireDefault(require("./section"));

var _componentCode = _interopRequireDefault(require("./component-code"));

var _question = require("../utils/question");

var _smartSuggestionUtils = require("../utils/smart-suggestion-utils");

var _button = require("../button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fields = [{
  name: 'text',
  label: 'This is the "label"',
  subLabel: 'this is the subLabel',
  onInput: true
}, {
  name: 'textWithSuggestions',
  label: 'This one has smart suggestions',
  subLabel: 'this is the subLabel',
  autoSuggestType: 'single',
  onInput: true
}, {
  name: 'medications',
  label: 'Multi-medication',
  type: 'medications'
}, {
  name: 'medication',
  label: 'Single Medication',
  type: 'medication'
}, {
  name: 'signature',
  label: 'Signature',
  type: 'signature',
  signatureLineName: 'Someone'
}, {
  label: 'Incrementor Field',
  name: 'incrementor',
  type: 'incrementor',
  fieldSpecificProps: {
    showStep: false,
    width: '140px',
    min: -5,
    max: 5
  },
  test: val => val < 1 ? 'value has to be more than zero' : ''
}, {
  label: 'Secured By',
  name: 'securedWith',
  type: 'choices',
  choices: [(0, _question.choice)('Tape'), (0, _question.choice)('Tegaderm')],
  showOther: true
}];

class FormsSection extends _preact.Component {
  constructor(props) {
    super(props);
    this.state = {
      incrementor: 0
    };
    fields.forEach(field => {
      if (!this.state.hasOwnProperty(field.name)) {
        this.state[field.name] = '';
      }
    });
  }

  updateValue(updates) {
    this.setState(updates, () => {});
  }

  render(_, state) {
    const processedFields = (0, _smartSuggestionUtils.buildQuestionList)(fields, this.state, {
      textWithSuggestions: {
        suggestions: [{
          score: 2,
          phrase: 'Jsjsj'
        }],
        deleting: false
      }
    });
    return (0, _preact.h)(_section.default, {
      title: "Forms"
    }, (0, _preact.h)(_componentCode.default, {
      name: "Form",
      code: "<Form\n  autocomplete=\"off\"\n  onSubmit={() => {\n    !state.missingItems && alert('finished')\n  }}\n  updateValue={updates => this.updateValue(updates)}\n  removeSuggestion={(fieldName, suggestion) =>\n    alert(`removeSuggestion(\"${fieldName}\", \"${suggestion}\")`)\n  }\n  fields={processedFields}\n  bottom={\n    <div>\n      <Button>Submit</Button>\n    </div>\n  }\n/>"
    }, (0, _preact.h)(_2.Form, {
      autocomplete: "off",
      onSubmit: () => {
        alert('submit called');
      },
      updateValue: updates => this.updateValue(updates),
      removeSuggestion: (fieldName, suggestion) => alert("removeSuggestion(\"".concat(fieldName, "\", \"").concat(suggestion, "\")")),
      fields: processedFields,
      bottom: (0, _preact.h)("div", {
        className: "mv3"
      }, (0, _preact.h)(_button.Button, {
        primary: true,
        large: true,
        type: "submit"
      }, "Submit"))
    }), (0, _preact.h)("div", {
      className: "f7"
    }, "Form Definition:", (0, _preact.h)("pre", null, (0, _preact.h)("code", {
      className: "f7"
    }, JSON.stringify(processedFields, null, 2))), "Form state:", (0, _preact.h)("pre", null, (0, _preact.h)("code", {
      className: "f7"
    }, JSON.stringify(state, null, 2))))));
  }

}

exports.FormsSection = FormsSection;