"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildQuestionList = exports.buildSuggestionList = exports.getAutoPopulatedValue = exports.removeCommaSeparatedItem = exports.addCommaSeparatedItem = exports.withoutText = exports.textAppended = void 0;

var _question = require("./question");

const textAppended = (existing, newPhrase) => {
  if (!existing) {
    return newPhrase;
  }

  let cleaned = existing.trim();

  if (cleaned.slice(-1)[0] !== '.') {
    cleaned = cleaned + '.';
  }

  return "".concat(cleaned, " ").concat(newPhrase);
};

exports.textAppended = textAppended;

const withoutText = (existing = '', phraseToRemove) => existing.replace(phraseToRemove, '').replace('  ', ' ').trim();

exports.withoutText = withoutText;

const getAsArray = (existing = '') => existing.split(',').map(item => item.trim()).filter(Boolean);

const addCommaSeparatedItem = (existing, newItem) => [...getAsArray(existing), newItem].join(', ');

exports.addCommaSeparatedItem = addCommaSeparatedItem;

const removeCommaSeparatedItem = (existing, toRemove) => getAsArray(existing).filter(item => item !== toRemove).join(', ');

exports.removeCommaSeparatedItem = removeCommaSeparatedItem;

const getAutoPopulatedValue = suggestions => {
  const totalSuggestions = suggestions.length;

  if (!totalSuggestions) {
    return '';
  }

  const firstSuggestionEntry = suggestions[0];
  const firstScore = firstSuggestionEntry.score;

  if (firstScore < 3) {
    return '';
  }

  const secondScore = suggestions[1] && suggestions[1].score || 0;
  const scoreDiff = firstScore - secondScore;
  const confidenceValue = scoreDiff / (firstScore + secondScore);
  return confidenceValue > 0.7 ? firstSuggestionEntry.phrase : '';
};

exports.getAutoPopulatedValue = getAutoPopulatedValue;

const buildSuggestionList = (matchingSuggestion, value, autoSuggestType) => matchingSuggestion && autoSuggestType ? matchingSuggestion.slice(0, 5).map(({
  phrase
}) => {
  let pressed;

  if (autoSuggestType === 'single') {
    pressed = value && value.trim() === phrase;
  } else {
    pressed = value && value.includes(phrase);
  }

  return {
    phrase,
    pressed
  };
}) : null;

exports.buildSuggestionList = buildSuggestionList;

const buildQuestionList = (config, data, suggestionsByField) => {
  const result = [];

  const addQuestion = item => {
    const {
      suggestions,
      deleting
    } = suggestionsByField[item.name] || {};
    let value;

    if (data.hasOwnProperty(item.name)) {
      value = data[item.name];
    } else if (item.autoSuggestType && suggestions) {
      value = getAutoPopulatedValue(suggestions);
    }

    const question = Object.assign({}, (0, _question.decorateFormItem)(item, value, data), {
      value,
      suggestions: buildSuggestionList(suggestions, value, item.autoSuggestType),
      suggestionsDeleting: !!deleting
    });
    result.push(question);

    if (question.choices) {
      question.choices.forEach(({
        val,
        questions
      }) => {
        if (question.value === val && questions) {
          questions.forEach(addQuestion);
        }
      });
    }
  };

  config.forEach(addQuestion);
  return result;
};

exports.buildQuestionList = buildQuestionList;